Write multiOmicDataSet properties to individual files.
Source:R/multiOmicDataSet.R
write_multiOmicDataSet_properties.RdThe sample_meta and annotation properties are written to CSV files, the
counts property is written to a subdirectory of CSV files, and the
analyses property is written to a subdirectory of CSV or RDS files
depending on the type of each analysis result.
Usage
write_multiOmicDataSet_properties(moo, output_dir = "moo")
## S7 method for class <MOObject::multiOmicDataSet>
write_multiOmicDataSet_properties(moo, output_dir = "moo")Arguments
- moo
multiOmicDataSet object to write properties from
- output_dir
Directory where the properties will be saved (default: "moo")
Examples
sample_metadata <- data.frame(sample_id = c("s1", "s2"), group = c("A", "B"))
counts_dat <- data.frame(
feature_id = c("gene1", "gene2"),
s1 = c(10, 20),
s2 = c(15, 25)
)
moo <- create_multiOmicDataSet_from_dataframes(sample_metadata, counts_dat)
output_dir <- tempfile()
write_multiOmicDataSet_properties(moo, output_dir)